==> aws-cdk-scala_2.13-0.9.0-sources.jar: io/burkard/cdk/services/athena/cfnWorkGroup/WorkGroupConfigurationUpdatesProperty.scala <==
package io.burkard.cdk.services.athena.cfnWorkGroup

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object WorkGroupConfigurationUpdatesProperty {

  def apply(
    enforceWorkGroupConfiguration: Option[Boolean] = None,
    resultConfigurationUpdates: Option[software.amazon.awscdk.services.athena.CfnWorkGroup.ResultConfigurationUpdatesProperty] = None,
    removeBytesScannedCutoffPerQuery: Option[Boolean] = None,
    publishCloudWatchMetricsEnabled: Option[Boolean] = None,
    requesterPaysEnabled: Option[Boolean] = None,
    bytesScannedCutoffPerQuery: Option[Number] = None,
    engineVersion: Option[software.amazon.awscdk.services.athena.CfnWorkGroup.EngineVersionProperty] = None
  ): software.amazon.awscdk.services.athena.CfnWorkGroup.WorkGroupConfigurationUpdatesProperty =
    (new software.amazon.awscdk.services.athena.CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.Builder)
      .enforceWorkGroupConfiguration(enforceWorkGroupConfiguration.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .resultConfigurationUpdates(resultConfigurationUpdates.orNull)
      .removeBytesScannedCutoffPerQuery(removeBytesScannedCutoffPerQuery.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .publishCloudWatchMetricsEnabled(publishCloudWatchMetricsEnabled.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .requesterPaysEnabled(requesterPaysEnabled.map(Boolean.box).getOrElse(java.lang.Boolean.FALSE))
      .bytesScannedCutoffPerQuery(bytesScannedCutoffPerQuery.orNull)
      .engineVersion(engineVersion.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.17.0-sources.jar: io/burkard/cdk/services/athena/cfnWorkGroup/WorkGroupConfigurationUpdatesProperty.scala <==
package io.burkard.cdk.services.athena.cfnWorkGroup

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object WorkGroupConfigurationUpdatesProperty {

  def apply(
    enforceWorkGroupConfiguration: Option[Boolean] = None,
    resultConfigurationUpdates: Option[software.amazon.awscdk.services.athena.CfnWorkGroup.ResultConfigurationUpdatesProperty] = None,
    removeBytesScannedCutoffPerQuery: Option[Boolean] = None,
    publishCloudWatchMetricsEnabled: Option[Boolean] = None,
    requesterPaysEnabled: Option[Boolean] = None,
    bytesScannedCutoffPerQuery: Option[Number] = None,
    engineVersion: Option[software.amazon.awscdk.services.athena.CfnWorkGroup.EngineVersionProperty] = None
  ): software.amazon.awscdk.services.athena.CfnWorkGroup.WorkGroupConfigurationUpdatesProperty =
    (new software.amazon.awscdk.services.athena.CfnWorkGroup.WorkGroupConfigurationUpdatesProperty.Builder)
      .enforceWorkGroupConfiguration(enforceWorkGroupConfiguration.map(Boolean.box).orNull)
      .resultConfigurationUpdates(resultConfigurationUpdates.orNull)
      .removeBytesScannedCutoffPerQuery(removeBytesScannedCutoffPerQuery.map(Boolean.box).orNull)
      .publishCloudWatchMetricsEnabled(publishCloudWatchMetricsEnabled.map(Boolean.box).orNull)
      .requesterPaysEnabled(requesterPaysEnabled.map(Boolean.box).orNull)
      .bytesScannedCutoffPerQuery(bytesScannedCutoffPerQuery.orNull)
      .engineVersion(engineVersion.orNull)
      .build()
}
